package com.demo.mongodb;

import com.alibaba.fastjson.JSONObject;
import com.demo.common.SpecialSecret;
import com.demo.constant.ResultStatus;
import com.demo.entity.dto.DeviceReturnDto;
import com.demo.entity.po.ExceptionRecord;
import com.demo.entity.vo.DeviceConfVo;
import com.demo.entity.vo.DeviceIdVo;
import com.demo.entity.vo.SensorVo;
import com.demo.service.DeviceService;
import com.demo.util.DeformedBase64;
import com.demo.util.ResultObject;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.mongodb.core.MongoTemplate;
import org.springframework.web.bind.annotation.*;


@RestController
@RequestMapping("/")
public class DevicecheatController {

    @Autowired
    private MongoTemplate mongoTemplate;
    @Autowired
    private DeviceService deviceService;


    /**
     *该接口主要负责在SDK所在的APP启动时，由服务器想SDK下发配置信息，
     * 包括风险软件列表、热更新、白名单等信息。
     *
     * @return
     * @throws Exception
     */
    @RequestMapping(value = "/deviceconf", method = RequestMethod.GET)
    @ResponseBody
    public ResultObject deviceconf(@ModelAttribute DeviceConfVo deviceConf) throws Exception {
        String result = deviceService.getDeviceConf(deviceConf);
        if(result == null){
            return new ResultObject(ResultStatus.FAIL);
        }
        return new ResultObject(result);
    }


    /**
     * 该接口主要负责在SDK所在的APP启动时，采集设备的硬件信息，
     * 同时由服务器生成唯一ID并返回。
     * @return
     * @throws Exception
     */
    @RequestMapping(value = "/deviceid",method = RequestMethod.POST)
    @ResponseBody
    public ResultObject deviceid(@RequestBody DeviceIdVo deviceIdVo) throws Exception {
        String result = deviceService.getDeviceId(deviceIdVo);
        if(result == null){
            return new ResultObject(ResultStatus.FAIL);
        }
        return new ResultObject(result);
    }


    /**
     * 传感器信息上报接口
     *     该接口主要负责在APP运行期间，定时的上报设备传感器或者状态信息
     * @return
     * @throws Exception
     */
    @RequestMapping(value = "/sensor", method = RequestMethod.POST)
    @ResponseBody
    public ResultObject sensor(@RequestBody SensorVo sensorVo) throws Exception {
        boolean result = deviceService.reciveSensorInfo(sensorVo);
        if(!result){
            return new ResultObject(ResultStatus.FAIL);
        }
        return new ResultObject();
    }


    /**
     * 异常日志上报接口
     *
     * 该接口主要功能是接收异常日志，帮助SDK开发者定位异常代码
     * @return
     * @throws Exception
     */
    @RequestMapping(value = "/exception", method = RequestMethod.POST)
    @ResponseBody
    public ResultObject exception(@RequestBody ExceptionRecord exceptionRecord) throws Exception {

        this.mongoTemplate.insert(exceptionRecord);
        return new ResultObject(ResultStatus.SUCCESS);
    }

}
